import matplotlib.pyplot as plt
import networkx as nx
from sqlparse import split as split_statements
from sql_metadata import Parser
from sql_metadata.keywords_lists import QueryType
import typer


def graph_from_script(script: str) -> nx.DiGraph:
    statements = split_statements(script)
    edges = []
    for statement in statements:
        parser = Parser(statement)
        if parser.query_type == QueryType.SELECT:
            raise ValueError("Only Ddl statements are allowed")

        tables = parser.tables
        target = tables[0]
        for source in tables[1:]:
            edges.append((source, target))

    return nx.DiGraph(edges)


def lineage(file_path: str, output: str = "lineage.png"):
    """Create lineage graph

    Takes the file path of the sql script and creates a png image,
    the path of which can be optionally specified.
    """
    graph = graph_from_script(open(file_path).read())
    nx.draw(graph, with_labels=True, font_weight="bold", font_size=10)
    plt.savefig(output)


def main():
    typer.run(lineage)
